%define debug_package %{nil}

Summary:	Internet traffic decoder and network forensic analysis tool

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		xplico
Version:	1.1.1
Release:	1%{?dist}
URL:		http://www.xplico.org/

License:	GPL

Group:		Applications/Forensics Tools
Source0:	%{name}-%{version}.tgz
%if 0%{?centos} == 5 || 0%{?centos} == 6
Source1:	%{name}-%{version}-py3.1.tgz
%endif
%if 0%{?fedora} >= 15 && 0%{?fedora} <= 17
Source2:	%{name}-%{version}-py3.2.tgz
%endif
%if 0%{?fedora} >= 18 && 0%{?fedora} <= 20
Source2:	%{name}-%{version}-py3.3.tgz
%endif
Patch1:		%{name}-%{version}-patch-001
Patch2:		%{name}-%{version}-patch-002
Patch3:		%{name}-%{version}-patch-003

BuildRoot:	%{buildroot}
BuildRequires:	GeoIP-devel
BuildRequires:	mysql-devel
BuildRequires:	sqlite-devel
BuildRequires:	libpcap-devel
BuildRequires:	nDPI-devel
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	gettext
Requires:	GeoIP
Requires:	mysql
Requires:	sqlite
Requires:	libpcap
Requires:	wireshark
Requires:	httpd
Requires:	php-pdo
Requires:	php
Requires:	recode
Requires:	sox
Requires:	lame
Requires:	videosnarf
Requires:	ghostpdl
Requires:	python3-httplib2
Requires:	nDPI
%if 0%{?fedora} || 0%{?centos} >= 7
Requires:	python3-psycopg2
%endif
%if 0%{?fedora} >= 18
BuildRequires:	python3 >= 3.3
Requires:	python3 >= 3.3
%endif
%if 0%{?fedora} >= 15 && 0%{?fedora} <= 17
Requires:	python3 >= 3.2, python3 < 3.3
BuildRequires:	python3 >= 3.2, python3 < 3.3
%endif
%if 0%{?centos} == 5 || 0%{?centos} == 6
Requires:	python3 >= 3.1, python3 < 3.2
BuildRequires:	python3 >= 3.1, python3 < 3.2
%endif
%if 0%{?centos} == 7
Requires:	python3 >= 3.3
BuildRequires:	python3 >= 3.3
%endif

%description
The goal of Xplico is extract from an internet traffic capture the
applications data contained.  For example, from a pcap file Xplico
extracts each email (POP, IMAP, and SMTP protocols), all HTTP contents,
each VoIP call (SIP), FTP, TFTP, and so on. Xplico isn’t a network
protocol analyzer. Xplico is an open source Network Forensic Analysis Tool
(NFAT).

%prep
%setup  -q
%patch1 -p1
%if 0%{?fedora} >= 18 || 0%{?centos} >= 7
%patch2 -p1
%endif
%patch3 -p1
################################################################################
# Python 3.1 correction
################################################################################
%if 0%{?centos} == 5 || 0%{?centos} == 6
tar zxf %{SOURCE1}
touch `tar ztf %{SOURCE1}`
%endif

################################################################################
# Python 3.2 correction
################################################################################
%if 0%{?fedora} >= 15 && 0%{?fedora} <= 17
tar zxf %{SOURCE2}
touch `tar ztf %{SOURCE2}`
%endif

################################################################################
# Get the GeoLite database
################################################################################
wget http://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.gz
if [ -f GeoLiteCity.dat.gz ]; then gunzip GeoLiteCity.dat.gz; fi

%build
%if 0%{?fedora} == 22
env CC="gcc -std=gnu89" %{__make}
%else
%{__make}
%endif

%install
make install DESTDIR=$RPM_BUILD_ROOT
################################################################################
# Add the script to manage the service and add the configuration file for the
# local web server.
################################################################################
%if 0%{?fedora} >= 17 || 0%{?centos} >= 7
%__install -Dp init.d/%{name} %{buildroot}%{_sbindir}/%{name}
mkdir -p %{buildroot}/usr/lib/systemd/system
cat > %{buildroot}/usr/lib/systemd/system/%{name}.service <<EOF
[Unit]
Description=The Xplico Open Source Network Forensics Analysis Tool
After=httpd.service

[Service]
Type=notify
Environment=LANG=C
Type=forking

ExecStart=%{_sbindir}/%name start
ExecReload=%{_sbindir}/%name restart
ExecStop=%{_sbindir}/%name stop

[Install]
WantedBy=multi-user.target
EOF
%else
%__install -Dp init.d/%{name} %{buildroot}/etc/init.d/%{name}
%endif
%__install -Dp httpd/%{name}.conf %{buildroot}/etc/httpd/conf.d/%{name}.conf
################################################################################
# Remove the database from the distribution. This is now handled conditionally
# when the package is installed.
################################################################################
rm -f %{buildroot}/opt/xplico/xplico.db

################################################################################
# Remove the apache2 stuff - we replace it with something else
################################################################################
rm -rf %{buildroot}/etc/apache2

%clean
%{__rm} -rf %{buildroot}

%post

%if 0%{?fedora} <= 15
/sbin/chkconfig --del xplico
/sbin/chkconfig --add xplico
%else
/usr/bin/systemctl disable xplico.service
/usr/bin/systemctl enable  xplico.service
%endif
XPLICO_BASE=/opt/xplico
DB=$XPLICO_BASE/xplico.db
DB_OLD=$XPLICO_BASE/xplico_old.db
DB_NEW=$XPLICO_BASE/xplico_new.db
XI=$XPLICO_BASE/xi/app/
XPLICO_SQLITE_BASE=$XPLICO_BASE/script/db/sqlite
PHPINI=/etc/php.ini
if grep -q '^post_max_size = 100M' $PHPINI ; then
	echo "Variable post_max_size in $PHPINI has already been set to the recommended 100M."
elif grep -q '^post_max_size = 8M' $PHPINI ; then
        echo "Resetting post_max_size in $PHPINI"
        sed --in-place '/post_max_size = 8M/s/^/post_max_size = 100M ; XPLICO /' $PHPINI
else
	echo "Variable post_max_size in $PHPINI is not the default (8M). Recommended value for xplico is 100M. Set by hand."
fi
if grep -q '^upload_max_filesize = 100M' $PHPINI ; then
	echo "Variable upload_max_filesize in $PHPINI has already been set to the recommended 100M."
elif grep -q '^upload_max_filesize = 2M' $PHPINI ; then
        echo "Resetting upload max file size in $PHPINI"
        sed --in-place '/upload_max_filesize = 2M/s/^/upload_max_filesize = 100M ; XPLICO /' $PHPINI
else
	echo "Variable upload_max_filesize in $PHPINI is not the default (2M). Recommended value for xplico is 100M. Set by hand."
fi
if grep -q '^short_open_tag = Off' $PHPINI ; then
        echo "Setting short open tag in $PHPINI"
        sed --in-place '/^short_open_tag = Off/s/^/short_open_tag = On ; XPLICO /' $PHPINI
else
	echo "Variable short_open_tag in $PHPINI is already set."
fi
if grep -q '^date.timezone' $PHPINI ; then
        echo "Timezone already set in $PHPINI - no change made."
else
        echo "Setting timezone to US/Eastern in $PHPINI - change by hand for different time zones."
        echo 'date.timezone = US/Eastern ; XPLICO' >> $PHPINI
fi

cd $XPLICO_SQLITE_BASE
if [ -e "$DB" ]; then
	echo "Preserving previous Xplico database"
%if 0%{?fedora} <= 15
	service xplico status | grep -q running
%else
	/usr/bin/systemctl status xplico.service 
%endif
	XPLICO_SERVER_STATUS=$?
	if [ "$XPLICO_SERVER_STATUS" -eq 0 ]; then
%if 0%{?fedora} <= 15
		service xplico stop
%else
		/usr/bin/systemctl stop xplico.service
%endif
	fi
	mv $DB $DB_OLD
	sh create_xplico_db.sh
	mv $DB $DB_NEW
	mv $DB_OLD $DB
	sh create_xplico_db.sh
	python3 upgrade_db.py
	rm -f $DB_NEW
	rm -rf /opt/xplico/xi/app/tmp/cache/models/*
	rm -rf /opt/xplico/xi/app/tmp/cache/views/*
	if [ "$XPLICO_SERVER_STATUS" -eq 0 ]; then
%if 0%{?fedora} <= 15
		service xplico start
%else
		/usr/bin/systemctl start xplico.service
%endif
	fi
else
	echo "Creating new Xplico database"
	sh create_xplico_db.sh
fi
chown apache.apache $DB
if [ -f /usr/bin/pcl6 ]; then
	cp -p /usr/bin/pcl6 /opt/xplico/bin
fi
if [ -f /usr/bin/videosnarf ]; then
	cp -p /usr/bin/videosnarf /opt/xplico/bin
fi

%preun
if [ $1 = 0 ]; then
%if 0%{?fedora} <= 15
	/sbin/service xplico stop > /dev/null 2>&1
	/sbin/chkconfig --del xplico
%else
	/usr/bin/systemctl stop xplico.service
	/usr/bin/systemctl disable xplico.service
%endif
fi
if [ -f /opt/xplico/bin/pcl6 ]; then
	rm -f /opt/xplico/bin/pcl6
fi
if [ -f /opt/xplico/bin/videosnarf ]; then
	rm -f /opt/xplico/bin/videosnarf
fi
PHPINI=/etc/php.ini
sed --in-place 's/^post_max_size = 100M ; XPLICO //' $PHPINI
sed --in-place 's/^upload_max_filesize = 100M ; XPLICO //' $PHPINI
sed --in-place '/^date.timezone = US\/Eastern ; XPLICO/d' $PHPINI
sed --in-place 's/^short_open_tag = On ; XPLICO //' $PHPINI

%files
%doc AUTHORS ChangeLog COPYING.CC_BY-NC-SA INSTALL LICENSE COPYING.GPLv2.0 DEPENDENCES README
%defattr(0644, apache, apache, 0755)
%attr(755, apache, apache)	/etc/httpd/conf.d/xplico.conf
%if 0%{?fedora} >= 17 ||0%{?centos} == 7
%attr(755, root, root)		%{_sbindir}/xplico
%attr(644, root, root)		/usr/lib/systemd/system/%{name}.service
%else
%attr(755, apache, apache)	/etc/init.d/xplico
%endif
%dir				/opt/xplico
%dir				/opt/xplico/cfg
%dir				/opt/xplico/script
%attr(644, apache, apache)	/opt/xplico/cfg/*
%attr(644, apache, apache)	/opt/xplico/GeoLiteCity.dat
%dir				/opt/xplico/log
%dir				/opt/xplico/script/db
%dir				/opt/xplico/script/db/mysql
%dir				/opt/xplico/script/db/sqlite
%attr(755, apache, apache)	/opt/xplico/script/db/sqlite/*.*
%attr(755, apache, apache)	/opt/xplico/script/mimedump.pyc
%attr(755, apache, apache)	/opt/xplico/script/xplico
%attr(755, apache, apache)	/opt/xplico/script/xml2pcap.php
%attr(755, apache, apache)	/opt/xplico/script/sqlite_demo.sh
%attr(755, apache, apache)	/opt/xplico/script/session_mng.pyc
%attr(644, apache, apache)	/opt/xplico/COPYING.CC_BY-NC-SA
%attr(644, apache, apache)	/opt/xplico/LICENSE
%dir				/opt/xplico/xi
%attr(644, apache, apache)	/opt/xplico/xi/README
%dir				/opt/xplico/xi/vendors
%dir				/opt/xplico/xi/vendors/shells
%dir				/opt/xplico/xi/vendors/shells/tasks
%attr(644, apache, apache)	/opt/xplico/xi/vendors/shells/tasks/empty
%dir				/opt/xplico/xi/vendors/shells/templates
%attr(644, apache, apache)	/opt/xplico/xi/vendors/shells/templates/empty
%dir				/opt/xplico/xi/plugins
%attr(644, apache, apache)	/opt/xplico/xi/plugins/empty
%dir				/opt/xplico/xi/app
%dir				/opt/xplico/xi/app/webroot
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/test.php
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css.php
%dir				/opt/xplico/xi/app/webroot/css
%dir				/opt/xplico/xi/app/webroot/css/themes
%dir				/opt/xplico/xi/app/webroot/css/themes/ui-darkness
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/jquery-ui-custom.css
%dir				/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_20_555555_1x400.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_ffffff_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_gloss-wave_25_333333_500x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_inset-soft_25_000000_1x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_highlight-soft_80_eeeeee_1x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_4b8e0b_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_inset-soft_30_f58400_1x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_222222_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_flat_30_cccccc_40x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/pbar-ani.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_flat_50_5c5c5c_40x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_40_ffc73d_1x400.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_a83300_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_cccccc_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_40_0078a3_1x400.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/style.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/webimages.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/facebookchat.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/cake.generic.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/html.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/mail.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/flows.css
%dir				/opt/xplico/xi/app/webroot/img
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/w3c_xhtml10.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/button-xplico.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/over_close.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/deft.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/tick_64.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/delete_64.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/slider.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/cake.power.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/button-iserm.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/over_white.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/database.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/disable.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/statistics.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/update.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/cake.icon.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/devel_empty.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/dot.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/loading.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/menu-bits.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/enable.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/cake.power.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/capanalysis.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/pcapsize.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/geoposition.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/w3c_css.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/version.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/devel.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/deft_link.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/relevance.html
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/index.php
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/.htaccess
%dir				/opt/xplico/xi/app/webroot/js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/check_ver.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/vendors.php
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/swfobject.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/http_get.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/jquery-ui-custom.min.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/flowplayer-3.2.2.min.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/jquery.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/jquery.tools.min.js
%dir				/opt/xplico/xi/app/webroot/files
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/xplico_voip_mix.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/flowplayer-3.2.2.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/xplico_voip.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/flowplayer.controls-3.2.1.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/open-flash-chart.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/favicon.ico
%dir				/opt/xplico/xi/app/vendors
%dir				/opt/xplico/xi/app/vendors/shells
%dir				/opt/xplico/xi/app/vendors/shells/tasks
%attr(644, apache, apache)	/opt/xplico/xi/app/vendors/shells/tasks/empty
%dir				/opt/xplico/xi/app/vendors/shells/templates
%attr(644, apache, apache)	/opt/xplico/xi/app/vendors/shells/templates/empty
%dir				/opt/xplico/xi/app/config
%attr(644, apache, apache)	/opt/xplico/xi/app/config/routes.php
%dir				/opt/xplico/xi/app/config/schema
%attr(644, apache, apache)	/opt/xplico/xi/app/config/schema/i18n.php
%attr(644, apache, apache)	/opt/xplico/xi/app/config/schema/sessions.php
%attr(644, apache, apache)	/opt/xplico/xi/app/config/schema/db_acl.php
%attr(644, apache, apache)	/opt/xplico/xi/app/config/core.php
%attr(644, apache, apache)	/opt/xplico/xi/app/config/database.php.sqlite3
%attr(644, apache, apache)	/opt/xplico/xi/app/config/acl.ini.php
%attr(644, apache, apache)	/opt/xplico/xi/app/config/bootstrap.php
%attr(644, apache, apache)	/opt/xplico/xi/app/config/database.php
%dir				/opt/xplico/xi/app/plugins
%dir				/opt/xplico/xi/app/plugins/datasources
%dir				/opt/xplico/xi/app/plugins/datasources/models
%dir				/opt/xplico/xi/app/plugins/datasources/models/datasources
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/amazon_associates_source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/soap_source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/ldap_source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/xmlrpc_source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/array_source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/couchdb_source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/csv_source.php
%dir				/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_db2.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_adodb.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_sybase.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_sqlite3.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_firebird.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_mysql_log.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_sqlsrv.php
%attr(644, apache, apache)	/opt/xplico/xi/app/plugins/datasources/models/datasources/dbo/dbo_odbc.php
%dir				/opt/xplico/xi/app/locale
%dir				/opt/xplico/xi/app/locale/urd
%dir				/opt/xplico/xi/app/locale/urd/LC_MESSAGES
%dir				/opt/xplico/xi/app/locale/deu
%dir				/opt/xplico/xi/app/locale/deu/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/deu/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/ita
%dir				/opt/xplico/xi/app/locale/ita/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/ita/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/fre
%dir				/opt/xplico/xi/app/locale/fre/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/fre/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/zh_tw
%dir				/opt/xplico/xi/app/locale/zh_tw/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/zh_tw/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/pt_br
%dir				/opt/xplico/xi/app/locale/pt_br/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/pt_br/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/rus
%dir				/opt/xplico/xi/app/locale/rus/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/rus/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/ara
%dir				/opt/xplico/xi/app/locale/ara/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/ara/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/hin
%dir				/opt/xplico/xi/app/locale/hin/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/hin/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/tur
%dir				/opt/xplico/xi/app/locale/tur/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/tur/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/eng
%dir				/opt/xplico/xi/app/locale/eng/LC_MESSAGES
%dir				/opt/xplico/xi/app/locale/por
%dir				/opt/xplico/xi/app/locale/por/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/por/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/zh_cn
%dir				/opt/xplico/xi/app/locale/zh_cn/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/zh_cn/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/locale/jpn
%dir				/opt/xplico/xi/app/locale/jpn/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/jpn/LC_MESSAGES/default.po
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/default.pot
%dir				/opt/xplico/xi/app/locale/spa
%dir				/opt/xplico/xi/app/locale/spa/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/locale/spa/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/models
%attr(644, apache, apache)	/opt/xplico/xi/app/models/feed_xml.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/httpfile.php
%dir				/opt/xplico/xi/app/models/behaviors
%attr(644, apache, apache)	/opt/xplico/xi/app/models/behaviors/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/models/irc_channel.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/syslog.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/ftp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/web.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/param.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/input.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/unknow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/unkfile.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/pjl.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/sip.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/icmpv6.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/tftp_file.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/sol.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/dns_message.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/fbchat.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/webmail.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/arp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/group.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/fbuchat.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/nntp_group.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/paltalk_exp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/irc.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/mm.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/paltalk_rooms.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/rtp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/nntp_article.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/telnet.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/ftp_file.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/pol.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/email.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/feed.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/webymsg.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/user.php
%dir				/opt/xplico/xi/app/models/datasources
%attr(644, apache, apache)	/opt/xplico/xi/app/models/mmscontent.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/tftp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/models/msn_chats.php
%dir				/opt/xplico/xi/app/controllers
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/feeds_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/pols_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/nntp_groups_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/configurations_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/arps_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/fbuchats_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/paltalk_exps_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/emails_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/sips_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/tftps_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/paltalk_rooms_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/webs_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/webmails_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/rfc822_addresses.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/mime_parser.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/ircs_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/icmpv6s_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/mms_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/unknows_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/users_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/inputs_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/httpfiles_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/msn_chats_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/commonlib.php
%dir				/opt/xplico/xi/app/controllers/php-ofc-library
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_hollow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_tooltip.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_shape.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_tags.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_axis_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_legend.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_axis.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_radar_axis_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_area_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_scatter.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_candle.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_glass.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_3d.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_right.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_dot.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_pie.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/open-flash-chart.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_stack.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_arrow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/README.txt
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/dot_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/open-flash-chart-object.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_radar_axis.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/JSON.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_axis_label.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_area_line.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_hbar.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_title.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_upload_image.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_menu.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_radar_spoke_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_area_hollow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/json_format.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_style.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_label.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_sketch.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_legend.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_scatter_line.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_filled.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_sugar.php
%dir				/opt/xplico/xi/app/controllers/components
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/components/xml2_pcap.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/components/search_path.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/components/xplico.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/components/xplico.php.orig
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/rtps_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/admins_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/unkfiles_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/telnets_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/dns_messages_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/sols_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/pjls_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/ftps_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/syslogs_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/app/controllers/webymsgs_controller.php
%dir				/opt/xplico/xi/app/tmp
%dir				/opt/xplico/xi/app/tmp/sessions
%dir				/opt/xplico/xi/app/tmp/cache
%dir				/opt/xplico/xi/app/tmp/cache/models
%dir				/opt/xplico/xi/app/tmp/cache/persistent
%dir				/opt/xplico/xi/app/tmp/cache/views
%dir				/opt/xplico/xi/app/tmp/tests
%attr(644, apache, apache)	/opt/xplico/xi/app/tmp/tests/empty
%dir				/opt/xplico/xi/app/tmp/logs
%attr(644, apache, apache)	/opt/xplico/xi/app/index.php
%dir				/opt/xplico/xi/app/libs
%attr(644, apache, apache)	/opt/xplico/xi/app/.htaccess
%dir				/opt/xplico/xi/app/views
%dir				/opt/xplico/xi/app/views/sips
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sips/called_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sips/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sips/caller_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sips/index.ctp
%dir				/opt/xplico/xi/app/views/webs
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webs/images.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webs/hijacking.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webs/method.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webs/play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webs/index.ctp
%dir				/opt/xplico/xi/app/views/layouts
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/licenses.ctp
%dir				/opt/xplico/xi/app/views/layouts/xml
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/xml/empty
%dir				/opt/xplico/xi/app/views/layouts/email
%dir				/opt/xplico/xi/app/views/layouts/email/html
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/email/html/empty
%dir				/opt/xplico/xi/app/views/layouts/email/text
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/email/text/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/rdf.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/cookies.ctp
%dir				/opt/xplico/xi/app/views/layouts/rss
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/rss/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/voip.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/fbchat.ctp
%dir				/opt/xplico/xi/app/views/layouts/js
%attr(644, apache, apache)	/opt/xplico/xi/app/views/layouts/js/empty
%dir				/opt/xplico/xi/app/views/errors
%attr(644, apache, apache)	/opt/xplico/xi/app/views/errors/empty
%dir				/opt/xplico/xi/app/views/httpfiles
%attr(644, apache, apache)	/opt/xplico/xi/app/views/httpfiles/index.ctp
%dir				/opt/xplico/xi/app/views/ftps
%attr(644, apache, apache)	/opt/xplico/xi/app/views/ftps/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/ftps/index.ctp
%dir				/opt/xplico/xi/app/views/configurations
%attr(644, apache, apache)	/opt/xplico/xi/app/views/configurations/dissectors.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/configurations/index.ctp
%dir				/opt/xplico/xi/app/views/tftps
%attr(644, apache, apache)	/opt/xplico/xi/app/views/tftps/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/tftps/index.ctp
%dir				/opt/xplico/xi/app/views/unkfiles
%attr(644, apache, apache)	/opt/xplico/xi/app/views/unkfiles/index.ctp
%dir				/opt/xplico/xi/app/views/paltalk_exps
%attr(644, apache, apache)	/opt/xplico/xi/app/views/paltalk_exps/chat.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/paltalk_exps/index.ctp
%dir				/opt/xplico/xi/app/views/emails
%attr(644, apache, apache)	/opt/xplico/xi/app/views/emails/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/emails/index.ctp
%dir				/opt/xplico/xi/app/views/feeds
%attr(644, apache, apache)	/opt/xplico/xi/app/views/feeds/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/feeds/xml.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/feeds/index.ctp
%dir				/opt/xplico/xi/app/views/webymsgs
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webymsgs/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webymsgs/index.ctp
%dir				/opt/xplico/xi/app/views/rtps
%attr(644, apache, apache)	/opt/xplico/xi/app/views/rtps/called_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/rtps/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/rtps/caller_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/rtps/index.ctp
%dir				/opt/xplico/xi/app/views/mms
%attr(644, apache, apache)	/opt/xplico/xi/app/views/mms/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/mms/index.ctp
%dir				/opt/xplico/xi/app/views/fbuchats
%attr(644, apache, apache)	/opt/xplico/xi/app/views/fbuchats/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/fbuchats/chats.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/fbuchats/index.ctp
%dir				/opt/xplico/xi/app/views/sols
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sols/add.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sols/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/sols/index.ctp
%dir				/opt/xplico/xi/app/views/admins
%attr(644, apache, apache)	/opt/xplico/xi/app/views/admins/uadd.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/admins/groups.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/admins/users.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/admins/gadd.ctp
%dir				/opt/xplico/xi/app/views/paltalk_rooms
%attr(644, apache, apache)	/opt/xplico/xi/app/views/paltalk_rooms/room.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/paltalk_rooms/index.ctp
%dir				/opt/xplico/xi/app/views/scaffolds
%attr(644, apache, apache)	/opt/xplico/xi/app/views/scaffolds/empty
%dir				/opt/xplico/xi/app/views/pages
%attr(644, apache, apache)	/opt/xplico/xi/app/views/pages/home.ctp
%dir				/opt/xplico/xi/app/views/icmpv6s
%attr(644, apache, apache)	/opt/xplico/xi/app/views/icmpv6s/index.ctp
%dir				/opt/xplico/xi/app/views/elements
%dir				/opt/xplico/xi/app/views/elements/email
%dir				/opt/xplico/xi/app/views/elements/email/html
%attr(644, apache, apache)	/opt/xplico/xi/app/views/elements/email/html/empty
%dir				/opt/xplico/xi/app/views/elements/email/text
%attr(644, apache, apache)	/opt/xplico/xi/app/views/elements/email/text/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/views/elements/empty
%dir				/opt/xplico/xi/app/views/ircs
%attr(644, apache, apache)	/opt/xplico/xi/app/views/ircs/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/ircs/channel.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/ircs/index.ctp
%dir				/opt/xplico/xi/app/views/pols
%attr(644, apache, apache)	/opt/xplico/xi/app/views/pols/add.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/pols/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/pols/index.ctp
%dir				/opt/xplico/xi/app/views/msn_chats
%attr(644, apache, apache)	/opt/xplico/xi/app/views/msn_chats/chat.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/msn_chats/index.ctp
%dir				/opt/xplico/xi/app/views/users
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/licenses.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/register.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/register_confirm.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/cpassword.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/cc_by_nc_sa.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/resend_reg.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/gpl.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/about.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/help.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/users/login.ctp
%dir				/opt/xplico/xi/app/views/inputs
%attr(644, apache, apache)	/opt/xplico/xi/app/views/inputs/geomap.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/inputs/index.ctp
%dir				/opt/xplico/xi/app/views/telnets
%attr(644, apache, apache)	/opt/xplico/xi/app/views/telnets/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/telnets/index.ctp
%dir				/opt/xplico/xi/app/views/arps
%attr(644, apache, apache)	/opt/xplico/xi/app/views/arps/index.ctp
%dir				/opt/xplico/xi/app/views/syslogs
%attr(644, apache, apache)	/opt/xplico/xi/app/views/syslogs/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/syslogs/index.ctp
%dir				/opt/xplico/xi/app/views/unknows
%attr(644, apache, apache)	/opt/xplico/xi/app/views/unknows/index.ctp
%dir				/opt/xplico/xi/app/views/dns_messages
%attr(644, apache, apache)	/opt/xplico/xi/app/views/dns_messages/graph.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/dns_messages/site_graph.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/dns_messages/index.ctp
%dir				/opt/xplico/xi/app/views/nntp_groups
%attr(644, apache, apache)	/opt/xplico/xi/app/views/nntp_groups/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/nntp_groups/alist.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/nntp_groups/index.ctp
%dir				/opt/xplico/xi/app/views/helpers
%attr(644, apache, apache)	/opt/xplico/xi/app/views/helpers/empty
%dir				/opt/xplico/xi/app/views/pjls
%attr(644, apache, apache)	/opt/xplico/xi/app/views/pjls/index.ctp
%dir				/opt/xplico/xi/app/views/webmails
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webmails/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/views/webmails/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/index.php
%attr(644, apache, apache)	/opt/xplico/xi/.htaccess
%dir				/opt/xplico/xi/cake
%dir				/opt/xplico/xi/cake/config
%dir				/opt/xplico/xi/cake/config/unicode
%dir				/opt/xplico/xi/cake/config/unicode/casefolding
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/2150_218f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0100_017f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/2460_24ff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/2c60_2c7f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/2c00_2c5f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0250_02af.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0530_058f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0500_052f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/2c80_2cff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/1f00_1fff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/ff00_ffef.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0370_03ff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0400_04ff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/1e00_1eff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0180_024F.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/0080_00ff.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/unicode/casefolding/2100_214f.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/config.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/config/paths.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/VERSION.txt
%dir				/opt/xplico/xi/cake/console
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/cake.bat
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/error.php
%dir				/opt/xplico/xi/cake/console/templates
%dir				/opt/xplico/xi/cake/console/templates/default
%dir				/opt/xplico/xi/cake/console/templates/default/classes
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/classes/controller.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/classes/fixture.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/classes/test.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/classes/model.ctp
%dir				/opt/xplico/xi/cake/console/templates/default/actions
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/actions/controller_actions.ctp
%dir				/opt/xplico/xi/cake/console/templates/default/views
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/views/form.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/views/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/views/home.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/default/views/index.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel
%dir				/opt/xplico/xi/cake/console/templates/skel/webroot
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/test.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/css.php
%dir				/opt/xplico/xi/cake/console/templates/skel/webroot/css
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/css/cake.generic.css
%dir				/opt/xplico/xi/cake/console/templates/skel/webroot/img
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/img/test-error-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/img/test-fail-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/img/test-skip-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/img/cake.icon.png
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/img/cake.power.gif
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/img/test-pass-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/index.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/.htaccess
%dir				/opt/xplico/xi/cake/console/templates/skel/webroot/js
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/js/empty
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/webroot/favicon.ico
%dir				/opt/xplico/xi/cake/console/templates/skel/vendors
%dir				/opt/xplico/xi/cake/console/templates/skel/vendors/shells
%dir				/opt/xplico/xi/cake/console/templates/skel/vendors/shells/tasks
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/vendors/shells/tasks/empty
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/app_helper.php
%dir				/opt/xplico/xi/cake/console/templates/skel/config
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/routes.php
%dir				/opt/xplico/xi/cake/console/templates/skel/config/schema
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/schema/i18n.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/schema/db_acl.sql
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/schema/sessions.sql
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/schema/sessions.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/schema/db_acl.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/schema/i18n.sql
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/core.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/database.php.default
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/acl.ini.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/config/bootstrap.php
%dir				/opt/xplico/xi/cake/console/templates/skel/plugins
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/plugins/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/locale
%dir				/opt/xplico/xi/cake/console/templates/skel/locale/eng
%dir				/opt/xplico/xi/cake/console/templates/skel/locale/eng/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/locale/eng/LC_MESSAGES/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/models
%dir				/opt/xplico/xi/cake/console/templates/skel/models/behaviors
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/models/behaviors/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/models/datasources
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/models/datasources/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/controllers
%dir				/opt/xplico/xi/cake/console/templates/skel/controllers/components
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/controllers/components/empty
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/controllers/pages_controller.php
%dir				/opt/xplico/xi/cake/console/templates/skel/tests
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/behaviors
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/behaviors/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/models
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/models/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/shells
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/shells/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/controllers
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/controllers/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/components
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/components/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/datasources
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/datasources/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/cases/helpers
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/cases/helpers/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/groups
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/groups/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tests/fixtures
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tests/fixtures/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/sessions
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tmp/sessions/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/cache
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/cache/models
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tmp/cache/models/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/cache/persistent
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tmp/cache/persistent/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/cache/views
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tmp/cache/views/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/tests
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tmp/tests/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/tmp/logs
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/tmp/logs/empty
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/index.php
%dir				/opt/xplico/xi/cake/console/templates/skel/libs
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/libs/empty
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/.htaccess
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/app_controller.php
%dir				/opt/xplico/xi/cake/console/templates/skel/views
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts/xml
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/xml/default.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts/email
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts/email/html
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/email/html/default.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts/email/text
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/email/text/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/flash.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/ajax.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts/rss
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/rss/default.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel/views/layouts/js
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/layouts/js/default.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel/views/errors
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/errors/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/views/scaffolds
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/scaffolds/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/views/pages
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/pages/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/views/elements
%dir				/opt/xplico/xi/cake/console/templates/skel/views/elements/email
%dir				/opt/xplico/xi/cake/console/templates/skel/views/elements/email/html
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/elements/email/html/default.ctp
%dir				/opt/xplico/xi/cake/console/templates/skel/views/elements/email/text
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/elements/email/text/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/elements/empty
%dir				/opt/xplico/xi/cake/console/templates/skel/views/helpers
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/views/helpers/empty
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/templates/skel/app_model.php
%dir				/opt/xplico/xi/cake/console/libs
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/console.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/acl.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/schema.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/i18n.php
%dir				/opt/xplico/xi/cake/console/libs/tasks
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/fixture.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/test.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/db_config.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/controller.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/view.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/project.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/bake.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/plugin.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/template.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/extract.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/tasks/model.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/bake.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/testsuite.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/shell.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/libs/api.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/cake.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/console/cake
%attr(644, apache, apache)	/opt/xplico/xi/cake/LICENSE.txt
%dir				/opt/xplico/xi/cake/libs
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/class_registry.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/router.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/debugger.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/set.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/magic_db.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/inflector.php
%dir				/opt/xplico/xi/cake/libs/view
%dir				/opt/xplico/xi/cake/libs/view/layouts
%dir				/opt/xplico/xi/cake/libs/view/layouts/xml
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/xml/default.ctp
%dir				/opt/xplico/xi/cake/libs/view/layouts/email
%dir				/opt/xplico/xi/cake/libs/view/layouts/email/html
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/email/html/default.ctp
%dir				/opt/xplico/xi/cake/libs/view/layouts/email/text
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/email/text/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/flash.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/ajax.ctp
%dir				/opt/xplico/xi/cake/libs/view/layouts/rss
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/rss/default.ctp
%dir				/opt/xplico/xi/cake/libs/view/layouts/js
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/layouts/js/default.ctp
%dir				/opt/xplico/xi/cake/libs/view/errors
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_behavior_file.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_action.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_helper_file.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_layout.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_connection.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_behavior_class.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/error500.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_scaffolddb.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_component_class.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/private_action.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_helper_class.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_table.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_model.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/scaffold_error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_controller.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/error404.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/errors/missing_component_file.ctp
%dir				/opt/xplico/xi/cake/libs/view/scaffolds
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/scaffolds/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/scaffolds/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/scaffolds/edit.ctp
%dir				/opt/xplico/xi/cake/libs/view/pages
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/pages/home.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/view.php
%dir				/opt/xplico/xi/cake/libs/view/elements
%dir				/opt/xplico/xi/cake/libs/view/elements/email
%dir				/opt/xplico/xi/cake/libs/view/elements/email/html
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/elements/email/html/default.ctp
%dir				/opt/xplico/xi/cake/libs/view/elements/email/text
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/elements/email/text/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/elements/sql_dump.ctp
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/media.php
%dir				/opt/xplico/xi/cake/libs/view/helpers
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/jquery_engine.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/app_helper.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/text.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/xml.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/number.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/session.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/paginator.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/cache.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/time.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/prototype_engine.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/rss.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/ajax.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/form.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/js.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/javascript.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/html.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helpers/mootools_engine.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/helper.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/view/theme.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/i18n.php
%dir				/opt/xplico/xi/cake/libs/log
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/log/file_log.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/security.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/folder.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/xml.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/overloadable_php5.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cake_log.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/file.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/l10n.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/overloadable_php4.php
%dir				/opt/xplico/xi/cake/libs/cache
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cache/memcache.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cache/file.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cache/apc.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cache/xcache.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cache.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/validation.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/sanitize.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/error.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cake_session.php
%dir				/opt/xplico/xi/cake/libs/controller
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/scaffold.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/controller.php
%dir				/opt/xplico/xi/cake/libs/controller/components
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/acl.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/security.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/session.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/request_handler.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/auth.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/email.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/components/cookie.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/app_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/pages_controller.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/controller/component.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/object.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/http_socket.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/overloadable.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/configure.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/multibyte.php
%dir				/opt/xplico/xi/cake/libs/model
%dir				/opt/xplico/xi/cake/libs/model/behaviors
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/behaviors/acl.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/behaviors/tree.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/behaviors/containable.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/behaviors/translate.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/connection_manager.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/model_behavior.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/db_acl.php
%dir				/opt/xplico/xi/cake/libs/model/datasources
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/datasource.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo_source.php
%dir				/opt/xplico/xi/cake/libs/model/datasources/dbo
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_mysql.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_oracle.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_mysqli.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_postgres.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_mssql.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_sqlite.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/cake_schema.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/model.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/model/app_model.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/cake_socket.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/libs/string.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/bootstrap.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/dispatcher.php
%attr(644, apache, apache)	/opt/xplico/xi/cake/basics.php
%attr(644, apache, apache)	/opt/xplico/COPYING.GPLv2.0
%dir				/opt/xplico/bin
%attr(755, apache, apache)	/opt/xplico/bin/mfile
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo_android.pyc
%attr(755, apache, apache)	/opt/xplico/bin/mwebymsg
%attr(755, apache, apache)	/opt/xplico/bin/wbm_libero.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_live.pyc
%attr(755, apache, apache)	/opt/xplico/bin/xplico
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_rossoalice.pyc
%attr(755, apache, apache)	/opt/xplico/bin/msite
%attr(755, apache, apache)	/opt/xplico/bin/dema
%dir				/opt/xplico/bin/modules
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_msn.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_webymsg.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ftp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_sll.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_cli_list.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_dns.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_icmpv6_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_lite_list.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_arp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_nntp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_irc.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_http.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_prism.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_paltalk_exp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_vlan.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_soft_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_rtp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_smtp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ppp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_l2tp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_fbwchat.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_grb.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pop.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_null.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp_grb.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_icmpv6.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ip.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_telnet.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_pcap2wav.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ipv6.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_webmail.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_rltm.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_sip.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_eth.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pcapf.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_httpfd.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_none.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ip_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_llc.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_pcap.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ieee80211.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_syslog.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_soft.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_pol.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_imap.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pjl.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ipp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_icmp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pol.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_lite.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pppoe.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_cli.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_radiotap.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_rtcp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_chdlc.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tftp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_mms.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_sdp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_paltalk.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_rltm_pol.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ppi.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp.so
%attr(755, apache, apache)	/opt/xplico/bin/mpaltalk
%attr(755, apache, apache)	/opt/xplico/bin/wbm_gmail.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo_v2.pyc
%attr(755, apache, apache)	/opt/xplico/bin/mfbc
%attr(755, apache, apache)	/opt/xplico/bin/mwmail
%attr(755, apache, apache)	/opt/xplico/bin/trigcap
%attr(755, apache, apache)	/opt/xplico/bin/wbm_aol.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_aol_v2.pyc
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_mgcp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_wa.so
%attr(755, apache, apache)	/opt/xplico/bin/wbm_rediff.pyc
%attr(755, apache, apache)	/opt/xplico/xi/app/controllers/mgcps_controller.php
%attr(755, apache, apache)	/opt/xplico/xi/app/controllers/whatsapps_controller.php
%attr(755, apache, apache)	/opt/xplico/xi/app/models/mgcp.php
%attr(755, apache, apache)	/opt/xplico/xi/app/models/whatsapp.php
%attr(755, apache, apache)	/opt/xplico/xi/app/views/mgcps/called_play.ctp
%attr(755, apache, apache)	/opt/xplico/xi/app/views/mgcps/caller_play.ctp
%attr(755, apache, apache)	/opt/xplico/xi/app/views/mgcps/index.ctp
%attr(755, apache, apache)	/opt/xplico/xi/app/views/mgcps/view.ctp
%attr(755, apache, apache)	/opt/xplico/xi/app/views/whatsapps/index.ctp
%attr(755, apache, apache)	/opt/xplico/xi/app/views/whatsapps/view.ctp

%changelog
* Mon Nov  9 2015 Lawrence R. Rogers <lrr@cert.org> 1.1.1-1
* Release 1.1.1-1
	* Whatsapp OS and Phone number
	* Added MGCP dissector
	* IMAP bug fixed
	* Updated for nDPI-1.7.0.

* Tue Aug 18 2015 Lawrence R. Rogers <lrr@cert.org> 1.1.0-4
* Release 1.1.0-4
	Recompiled for nDPI-1.7.0.

* Mon Jun 29 2015 Lawrence R. Rogers <lrr@cert.org> 1.1.0-3
* Release 1.1.0-3
	Recompiled for nDPI-1.6.

* Wed Sep  3 2014 Lawrence R. Rogers <lrr@cert.org> 1.1.0-2
* Release 1.1.0-2
	Changes for CentOS/RHEL 7

* Mon May 12 2014 Lawrence R. Rogers <lrr@cert.org> 1.1.0-1
* Release 1.1.0-1
	xplico 1.1.0
		* Performance improved
		* nDPI updated
		* IRC bug fixed
		* HTTP bug fixed
		* VoIP (SIP, RTP) bug fixed
		* FTP bug fixed
		* changed the FaceBook DB tables
		* Null/Loopback dissector
		* Cisco HDLC dissector
		* Libero.it and RossoAlice webmail decoding
		* Yahoo messenger (web and mobile)
		* Dig using file signatures (unknown flows)

* Thu Apr 24 2014 Lawrence R. Rogers <lrr@cert.org> 1.0.1-5
* Release 1.0.1-5
	For Fedora, there is now a systemd config file and the old /etc/init.d/xplico is now in /usr/sbin.

* Tue Jan 07 2014 Lawrence R. Rogers <lrr@cert.org> 1.0.1-4
* Release 1.0.1-4
	Fix for Fedora 19 and 20 and CentOS/RHEL 6 for setsocketopt in system/dema/session_decoding.c

* Fri Aug 02 2013 Lawrence R. Rogers <lrr@cert.org> 1.0.1-3
* Release 1.0.1-3
	Patch for Fedora 19

* Tue Jul 17 2012 Lawrence Rogers <lrr@cert.org> 1.0.0-2
* Release 1.0.0-2
	For beyond Fedora 16, now starts, stops, and queries the daemon status using systemctl.
	Also, adjusts /etc/php.ini so that xplico starts and runs.

* Fri Feb 10 2012 Lawrence Rogers <lrr@cert.org> 1.0.0-1
* Release 1.0.0-1
	* SQLite dispatcher performance improved
	* added the PPI dissector
	* added the syslog dissector
	* added "Bogus IP length" correction with checksum verification disabled
	* new Facebook Chat dissector for the new Facebook chat protocol
	* SIP dissector improved
	* IMAP dissector improved and bugs fixed
	* DNS dissector PIPI improved
	* Yahoo Webmail bugs fixed
	* Live/Hotmail WebMail Spanish version
	* GeoMap improved
	* PCap-over-IP

* Sun Jan 15 2012 Lawrence Rogers <lrr@cert.org> 0.7.1-1
* Release 0.7.1-1
	* RTP bug fixed
	* dispatcher core functionality bug fixed
	* mfile manipulator bug fixed
	* XI bugs fixed
	* added DB migration tool

* Mon Nov 7 2011 Lawrence Rogers <lrr@cert.org> 0.7.0-1
* Release 0.7.0-1
	* upgraded XI to Cakephp 1.3
	* added the ICMPv6 dissector
	* Ethernet dissector improved (necessary for ICMPv6)
	* deadlock fixed
	* fixed the communication bug from xplico and manipulators
	* SDP dissector bug fixes
	* SIP and TCP dissectors improved
	* WebMail manipulator and all python3 scripts improved (ready to new webmail entry... see pol ;) )
	* added pcap file name on CLI report screen
	* capture modules log improved
	* new GeoIP version: 1.4.8
	* added IPv6 Hop-by-Hop Options
	* Xplico and all Manipulators with dual stack (IPv4, IPv6)
	* XI language localization
	* DNS bugfix
	* added the  MDNS dissector
	* added AOL WebMail
	* added Yahoo! WebMail
	* added Yahoo! Mail for Andorid Mobile
	* added Gmail

* Mon Jun 6 2011 Lawrence Rogers <lrr@cert.org> 0.6.3-1
* Release 0.6.3-1
	* xplico 32/64bit version
	* new decoding manager (DeMa) version 0.3.1
	* mfile manipulator (HTTP file transfare) bug fixes
	* WebMail scripts improved
	* HTTP dissector improved
	* upgraded the XI javascript libraries

* Tue May 3 2011 Lawrence Rogers <lrr@cert.org>  0.6.2-1
* Revision 1: Upgrade to 0.6.2 doing the following:
	l7-patterns for all flows/protocols not decoded by xplico
	Xplico Interface (XI) improved
	python3 porting of many script
	realtime capture module improved
	facebook chat realtime view
	UTC/localtime bug fixes
	l2tp dissector bug fixes
	cli and lite dispatchers bug fixes
	telnet dissector bug fixes

* Tue Mar 1 2011 Lawrence Rogers <lrr@cert.org>  0.6.1-6
* Revision 6: The /etc/init.d/xplico script no longer specific the start and stop levels.
	      These should be done identical to and after httpd, so that xplico is
		set to start after httpd.

* Fri Dec 10 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-5
* Revision 5: Fixed init.d script so that it waits until httpd starts

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-4
* Revision 4: Fixed init.d script so that it is started after httpd

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-3
* Revision 3: Stops and restarts the server, if necessary, before adding any tables and PRAGMA values

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-2
* Revision 2: Changed the postun script to add the msn_chats and paltalk_rooms tables to an existing database.
		Also the foreign_keys PRAGMA was turned on and the auto_vacuum value displayed.`

* Tue Dec 7 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-1
* Revision 1: Version 0.6.1 from www.xplico.org

* Mon Nov 29 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-10
- Revision 10: Improved (fixed?) /etc/init.d/xplico so that it waits longer for httpd to start.
  Also added httpd as a service start dependency.

* Fri Nov 19 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-9
- Revision 9: 

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-8
- Revision 8: Correctly removes pcl6 and videosnarf as pre-uninstall scripts so that the
  /opt/xplico hierarchy can be completely removed if possible when xplico is removed.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-7
- Revision 7: Removed pcl6 and videosnarf and made those packages prerequisites. The needed
  binaries are then copied into the /opt/xplico hierarchy using the post-install script.
  Also, the correct syntax for creating the dabase is used.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-6
- Revision 6: Added pcl6 and videosnarf

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org>  0.6.0-5
- Revision 5: Fixed permissions to match those of the Debian package
  Also preserves any existing database by creating the database in the post-install script,
  as needed.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-4
- Revision 4: Gave execute permissions to everything in the bin directory
